// $Id$
/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.cdm.ext.geo;

import java.awt.Color;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.xml.stream.XMLStreamException;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.description.Distribution;
import eu.etaxonomy.cdm.model.description.PresenceAbsenceTermBase;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.location.NamedArea;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;

/**
 * @author a.kohlbecker
 * @date 18.06.2009
 * @author n.hoffmann
 *
 */
public interface IEditGeoService {

	/**
	 * Retrieve a parameter string to pass to an EditGeoService endpoint
	 * The endpoint will deliver a  a map generated by the Edit Geo Service for the given
	 * <code>TaxonDescription</code>
	 *
	 * @param taxonDescriptions
	 * 			A List of <code>TaxonDescription</code> holding the distribution data
	 * @param presenceAbsenceTermColors
	 * 			A map that classifies which <code>PresenceAbsenceTermBase</code> should
	 * 			be assigned which <code>Color</code>
	 * @param width
	 * 			The width of the map image
	 * @param height
	 * 			The height of the map image
	 * @param bbox
	 *
	 * @param backLayer
	 * @return
	 *
	 */
	public String getDistributionServiceRequestParameterString(
			List<TaxonDescription> taxonDescriptions,
			Map<PresenceAbsenceTermBase<?>, Color> presenceAbsenceTermColors,
			int width, int height, String bbox, String backLayer,
			List<Language> langs);


	/**
	 *
	 * @param distributions
	 * @param presenceAbsenceTermColors
	 * @param width
	 * @param height
	 * @param bbox
	 * @param backLayer
	 * @param langs
	 * @return
	 */
    public String getDistributionServiceRequestParameterString(Set<Distribution> distributions, Map<PresenceAbsenceTermBase<?>, Color> presenceAbsenceTermColors, int width,
            int height, String bbox, String backLayer, List<Language> langs);


	/**
	 * Retrieve a parameter string to pass to an EditGeoService endpoint
	 * The endpoint will deliver a  a map generated by the Edit Geo Service for the given
	 * <code>TaxonDescription</code>
	 *
	 * @param description
	 * 			The <code>TaxonDescription</code> holding the distribution data
	 * @param presenceAbsenceTermColors
	 * 			A map that classifies which <code>PresenceAbsenceTermBase</code> should
	 * 			be assigned which <code>Color</code>
	 * @param width
	 * 			The width of the map image
	 * @param height
	 * 			The height of the map image
	 * @param bbox
	 *
	 * @param backLayer
	 * @return
	 *
	 * @deprecated use {@link #getDistributionServiceRequestParameterString(List, Map, int, int, String, String, List)} instead
	 */
	@Deprecated
	public String getDistributionServiceRequestParameterString(TaxonDescription description,
			Map<PresenceAbsenceTermBase<?>,Color> presenceAbsenceTermColors,
			int width,
			int height,
			String bbox,
			String backLayer,
			List<Language> langs);


	public String getOccurrenceServiceRequestParameterString(
			List<SpecimenOrObservationBase> specimensOrObersvations,
			Map<Class<? extends SpecimenOrObservationBase>,Color> specimenOrObservationTypeColors,
			Boolean doReturnImage,
			Integer width,
			Integer height,
			String bbox,
			String backLayer);

	/**
	 * Adds an area mapping (CDM area -> geo service area). It is recommended to set the mapping
	 * in a persistent way, so it is available after restarting the application.
	 * @param area
	 * @param geoServiceArea
	 * @throws XMLStreamException
	 */
	public void setMapping(NamedArea area, GeoServiceArea geoServiceArea);

}
